package com.goldenwater.slaj.eme.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eme.mapper.BusiPlanCountMapper;
import com.goldenwater.slaj.eme.domain.BusiPlanCount;
import com.goldenwater.slaj.eme.service.IBusiPlanCountService;

/**
 * 应急预案统计 服务层实现
 */
@Service
public class BusiPlanCountServiceImpl implements IBusiPlanCountService {

    @Autowired
    private BusiPlanCountMapper busiPlanCountMapper;

    @Override
    public BusiPlanCount selectBusiPlanCountByGuid(String guid) {
        return busiPlanCountMapper.selectBusiPlanCountByGuid(guid);
    }

    @Override
    public List<BusiPlanCount> selectBusiPlanCountList(BusiPlanCount busiPlanCount) {
        return busiPlanCountMapper.selectBusiPlanCountList(busiPlanCount);
    }

    @Override
    public int insertBusiPlanCount(BusiPlanCount busiPlanCount) {
        return busiPlanCountMapper.insertBusiPlanCount(busiPlanCount);
    }

    @Override
    public int updateBusiPlanCount(BusiPlanCount busiPlanCount) {
        return busiPlanCountMapper.updateBusiPlanCount(busiPlanCount);
    }

    @Override
    public int deleteBusiPlanCountByGuid(String guid) {
        return busiPlanCountMapper.deleteBusiPlanCountByGuid(guid);
    }

    @Override
    public int deleteBusiPlanCountByGuids(String[] guids) {
        return busiPlanCountMapper.deleteBusiPlanCountByGuids(guids);
    }
}
